package App::nauniq;

our $VERSION = '0.07'; # VERSION

1;
# ABSTRACT: Non-adjacent uniq

__END__

=pod

=encoding UTF-8

=head1 NAME

App::nauniq - Non-adjacent uniq

=head1 VERSION

This document describes version 0.07 of App::nauniq (from Perl distribution App-nauniq), released on 2015-01-03.

=head1 SYNOPSIS

See the command-line script L<nauniq>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-nauniq>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-App-nauniq>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-nauniq>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
